/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////																		         ////////////////////////////
/////////////////////////////				        REPLICATION STATA FILE FOR: 					          ///////////////////////////
////////////////////////////   'ARE CONSUMERS WILLING TO SWITCH TO SMART TIME OF USE ELECTRICITY TARIFFS?'     //////////////////////////
///////////////////////////	                                                                                    /////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////																		         
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

set more off

// Open dataset
use "Will consumers switch to time of use tariffs - loss aversion and electic cars.dta", clear

// Ensuring data is -svyset- to account for survey design (so weighted analysis can be used)
* svyset the data
svyset [pweight=weight]

*** Figure 1('Flow of Study Participants') and Table 1 ('Measuring loss aversion using simple experiments') were created in MS Word

************************************************
* Table 2 - Characteristics of all study participants
************************************************
// Cell means, with sample weights and standard error for selected characteristics
foreach X in female age  fulltime parttime unemployed retired student noresponsework educ  noqualif qualif16 post16 undergrad higher educnoresponse socialgrade  occupants homeowner prent srent othertenure gas electric otherheat touyes touno toudk i.lossaversion lossaversion{
svy: mean `X'
}

************************************************
* Figure 2 - Variation in stated willingness to switch to the smart time of use tariff
************************************************
tab switch
* The raw data was then used to create Figure 2 in MS Excel 

************************************************
* Table 3 - Average treatment effects on willingness to switch to Off-Peak 3-Rate Tariff - PAP specification
************************************************

// Column 1: covariates not reported in results table 
svy: regress switch t1 t2 t3  lossaverse noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure

// Column 2: Ordered logit robustness check
svy: ologit switch t1 t2 t3  lossaverse noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure 

* NB removed 'decisionmaker' from all regressions as there was minimum variation, as per analysis plan (decision maker indicated whether person had decision making responsibility for changing household supplier or tariff)

************************************************
* Table 4 - Modelling willingness to switch to the Off-Peak 3-Rate Tariff
************************************************

// Willingness to switch modelled on 7-point Likert scale
svy: regress switch t1 t2 t3 noqualif qualif16 undergrad higher educnoresponse female age1 age2 age4 age5 srenter prenter othertenure parttime unemployed retired student noresponsework lifestylewrong lifestyleright timers washingtimer dryertimer dishtimer ownselectricv gas otherheat occupants kids switch2013 switch2014 hastou lossaverse prepayment i.region

************************************************
* Figure 3 - Willingness to switch is negatively correlated with loss-aversion
************************************************
graph bar switch, over (lossaverse)

/////////////////////////////////////////////////////////////////////////////////////////////////
//////////////                   RESULTS IN SUPPLEMENTARY MATERIAL                //////////////
////////////////////////////////////////////////////////////////////////////////////////////////

************************************************
* Appendix B Manipulation checks
************************************************

* Table B.1: Manipulation of independent variables
* manipulation checks 
foreach Y in good bad meonly both {

// COLUMN 1-3: in reference to control group
regress `Y' t1 t2 t3 

// COLUMN 4: in reference to gain-framed groups
regress `Y' t1t3

// COLUMN 5: in reference to private-interests only groups
regress `Y' t2t3 

** 'good' - mostly about good things that can happen
** 'bad' - mostly about bad things
** 'meonly' - just about private interests
** 'both' - about both private and public interests
}

* Table B.2: Message evaluation and knowledge
*** Column 1-3: Comparing each treatment group to the control (T1, T2, T3 to T0)
// easy 
regress Q7a_0 t1 t2 t3 {
// interesting
regress Q7b_0 t1 t2 t3
// believable
regress Q7c_0 t1 t2 t3
// knowledge about tariff score (using a composite measure of knowledge items)
* first create composite measure of knowledge items and test its internal reliability using Cronbach's alpha
alpha  Q6_0 Q6_1 Q6_2 Q6_3, std generate (knowledge)
//  Q6_0, Q6_1, Q6_2 and Q6_3 are the individual questions testing knowledge of tariff
// see http://www.stata.com/manuals13/mvalpha.pdf for how to interpret results of alpha test
* run regression using composite measure of knowledge
regress knowledge t1 t2 t3

*** Column 4: Comparing loss-framed groups to gain-framed groups (T1&T3 to T0&T2)

// easy
regress Q7a_0 t1t3
// interesting
regress Q7b_0 t1t3
// believable
regress Q7c_0 t1t3
// knowledge
regress knowledge t1t3

*** Column 5: Comparing social interest groups to private interest groups (T2&T3 to T0&T1)
// easy
regress Q7a_0 t2t3
// interesting
regress Q7b_0 t2t3
// believable
regress Q7c_0 t2t3
// knowledge
regress knowledge t2t3
}


************************************************
* Appendix D. Randomisation balance check
************************************************

// Columns (1)-(4): descriptive statistics by experimental group
by tariff: sum female age  fulltime parttime unemployed retired student noresponsework  noqualif qualif16 post16 undergrad higher educnoresponse touyes touno toudk lossaverse

// Hypothesis tests to check randomization worked on baseline descriptive statistics only (using OLS following Blattman paper)
* Column (5): Comparing each treatment group to the control (T1, T2, T3 to T0)
foreach Y in female age  fulltime parttime unemployed retired student noresponsework noqualif qualif16 post16 undergrad higher educnoresponse touyes touno toudk  lossaverse {
regress `Y' t1 t2 t3
}

* Column (6): Comparing loss-framed groups to gain-framed groups (T1&T3 to T0&T2)
foreach Y in female age  fulltime parttime unemployed retired student noresponsework noqualif qualif16 post16 undergrad higher educnoresponse socialgrade england wales scotland yessolely yesjointly notresponsible touyes touno toudk  lossaversion {
regress `Y' t1t3
}

* Column (7): Comparing social interest groups to private interest groups (T2&T3 to T0&T1)
foreach Y in female age  fulltime parttime unemployed retired student noresponsework noqualif qualif16 post16 undergrad higher educnoresponse socialgrade england wales scotland yessolely yesjointly notresponsible touyes touno toudk  lossaversion {
regress `Y' t2t3
}


/////////////////////////////////////////////////////////////////////////////////////////////////
//////////////             RESULTS REFERRED TO IN PAPER BUT NOT REPORTED          //////////////
////////////////////////////////////////////////////////////////////////////////////////////////


************************************************
* Redefining the control group to estimate treatment effect of message-framing
************************************************

// Does loss-framing boost willingness to switch to Off-Peak 3-Rate Tariff? (comparing both loss-framed tariffs to both gain-framed tariffs)
{
* PAP specification
// No controls
svy: regress switch t1t3

// With covariates
svy: regress switch t1t3 lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure

// Ordered logit robustness check
svy: ologit switch t1t3 lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure
}

// Does emphasising social benefits boost willingness to switch to Off-Peak 3-Rate Tariff? (comparing environmental messages to money only messages)
{
* PAP specification
// No controls
svy: regress switch t2t3

// With PAP covariates
svy: regress switch t2t3 lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure

// Ordered logit robustness check
svy: ologit switch t2t3 lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure
}

************************************************
* Does loss-framing combined with emphasising social benefits boost willingness to switch to Off-Peak 3-Rate Tariff more than any other group? (comparing group 3 to all others)
************************************************
{
* PAP specification
// No controls
svy: regress switch t3only

// With covariates
svy: regress switch t3only lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure

// Ordered logit robustness check
svy: ologit switch t3only lossaversion noqualif qualif16 undergrad higher educnoresponse female prenter srenter  othertenure
}

************************************************
* Does loss-framing boost willingness to switch to the Off-Peak 3-Rate Tariff amongst the loss-averse? (interaction model)
************************************************

* firstly creating interaction term dummies manually with lossaverse0 as reference group for column 3 and column 6 specification
gen t1t3_lossaverse1=t1t3*lossaverse1 {
gen t1t3_lossaverse2=t1t3*lossaverse2
gen t1t3_lossaverse3=t1t3*lossaverse3
gen t1t3_lossaverse4=t1t3*lossaverse4
gen t1t3_lossaverse5=t1t3*lossaverse5
gen t1t3_lossaverse6=t1t3*lossaverse6

* OLS
// No controls
svy: regress switch t1t3 lossaversion t1t3#c.lossaversion

// With covariates
svy: regress switch t1t3 lossaversion t1t3#c.lossaversion noqualif qualif16 undergrad higher educnoresponse female srenter prenter othertenure

// Dummy spec: compared to people who are not loss-averse (lossaverse0 is reference group)
svy: regress switch t1t3  lossaverse1 lossaverse2 lossaverse3 lossaverse4 lossaverse5 lossaverse6 t1t3_lossaverse1 t1t3_lossaverse2 t1t3_lossaverse3 t1t3_lossaverse4 t1t3_lossaverse5 t1t3_lossaverse6 noqualif qualif16 undergrad higher educnoresponse female srenter prenter othertenure 

* Ordered logit robustness check 
// No controls
svy: ologit switch t1t3 lossaversion t1t3#c.lossaversion 
// With covariates
svy: ologit switch t1t3 lossaversion t1t3#c.lossaversion noqualif qualif16 undergrad higher educnoresponse female srenter prenter othertenure
// Dummy spec: compared to people who are not loss-averse (lossaverse0 is reference group)
svy: ologit switch t1t3 lossaverse1 lossaverse2 lossaverse3 lossaverse4 lossaverse5 lossaverse6 t1t3_lossaverse1 t1t3_lossaverse2 t1t3_lossaverse3 t1t3_lossaverse4 t1t3_lossaverse5 t1t3_lossaverse6 noqualif qualif16 undergrad higher educnoresponse female srenter prenter othertenure 
}

///////////////////
///////////			MULTIPLE COMPARISONS CORRECTION
///////////////////

** using the parmest command to create a new dataset that contains the p-values etc for the above regression analysis and saving as new dataset
parmest, label saving(parms1.dta)

// opening parms file
use "C:\Users\parms1.dta", clear

* dropping the variable that contains the p-values so that I can run multproc and smileplot commands
drop __000001

** running multproc to obtain uncorrected and corrected p-values 
// 'pvalue (p)' tells stata the name of the variable in the dataset that contains the p-values
// 'method (simes' - tells stata to use the Benjamini and Hochberg (1995) correction for multiple comparisons to minimise the False Discovery Rate (FDR)
* significant at 5 percent level correction
multproc, pvalue(p) method (simes)
* significant at 1 percent level correction
multproc, pvalue(p) method (simes) puncor (0.01)
* significant at 0.1 percent level correction
multproc, pvalue(p) method (simes) puncor (0.001)

// output
Method: simes
Uncorrected overall critical P-value: .05
Number of P-values: 23
Corrected overall critical P-value: .01521739
Number of rejected P-values: 7

Method: simes
Uncorrected overall critical P-value: .01
Number of P-values: 23
Corrected overall critical P-value: .0026087
Number of rejected P-values: 6

. multproc, pvalue(p) method (simes) puncor (0.001)

Method: simes
Uncorrected overall critical P-value: .001
Number of P-values: 23
Corrected overall critical P-value: .00026087
Number of rejected P-values: 6
